API. Developer guide
BASE URL
All requests to the API-call must have a baseUrl.
The baseUrl depends on the it infrastructure where the client application module is deployed
baseUrl for Demo-peers – http://localhost:5000
APIKeyHeader
API keys can generate by calling the dedicated API method. Furthermore, API keys can have a limited scope and cover only some API methods. Lastly, they can revoke at any time. This range of possibilities makes API keys well suited for separating the API access rights across multiple applications or use cases. Finally, the loss of an API key is easily manageable.
You can manage your API keys programmatically with API-request.
For getting API-key you need to send next request
GET /auth/getToken
token: eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpZCI6IjkxMjUzOWUx
Generated api-key available for use within 24 hours.
Security scheme type:
API Key
Header parameter name:
Authorization
Send request
All use cases can be achieved by using this API method. Everything from sending a simple single request, up to batch sending of requests with a single API request.
Integration essentials and developer toolbox
POST /api/ createrequest
Base URL: Please login to see full path.
AUTHORIZATIONS:
APIKeyHeader
REQUEST BODY SCHEMA:
application/json
| Parameters | Type | Describe | |
| type_request | string |
Indicator of the type of information that we are looking for in this request. Possible values: ‘All categories’, |
|
| value | Array of objects | All information identification of all request. | |
| IdDocument | string | ID/Number document of person. Used in the block “request” | |
| PhoneNumber | string | Phone number of person. Can use next format ‘+380999999999’ or ‘380999999999’ or ‘0999999999’’. Used in the block “request” | |
Example:
{
"type_request" : ["Address", "Consumer Profile"],
"value" : [
{ "IdDocument" : "NK5673-567","PhoneNumber" : "380660941277" } ,
{ "IdDocument" : "TR6223-34","PhoneNumber" : " "},
{ "IdDocument" : " ","PhoneNumber" : "380660941277"}
]
}
Default successful response
REQUEST BODY SCHEMA:
application/json
| Parameters | Type | Describe | |
| response | object |
object (ApiRequestStatus) |
|
| parametrRequest | Array of objects | All information identification of all request. | |
| IdDocument | string | ID/Number document of person. Used in the block “request” | |
| PhoneNumber | string | Phone number of person. Can use next format ‘+380999999999’ or ‘380999999999’ or ‘0999999999’’. Used in the block “request” | |
| idRequest | string | System id of request | |
Example:
{
"parametrRequest": [
{
"idDocument": "NK5673-567",
"phoneNumber": "380660941277",
"idRequest": "30ce8f1f-5d39-4e37-85f0-cbd942ff3a95"
},
{
"idDocument": "TR6223-34",
"phoneNumber": " ",
"idRequest": "193faa6e-020e-4a36-9791-5b1ac445cf38"
},
],
"response": {
"statusCode": 201,
"reasonPhrase": "Created",
"isSuccessStatusCode": true
}
}
Get Respond
All use cases can be achieved by using this API method. Everything from getting an answer of a simple single request, up to batch sending of requests with a single API request.
Integration essentials and developer toolbox
POST /api/respond
Base URL: Please login to see full path.
AUTHORIZATIONS:
APIKeyHeader
REQUEST BODY SCHEMA:
application/json
| Parameters | Type | Describe |
| type_request | string |
Indicator of the type of information that we are looking for in this request. Possible values: ‘All categories’, |
| idRequest | Array of string | Array of System Id of request |
| period | number | Time span in n minutes. As a result, the results of all queries for the last n minutes will be return. |
Example:
{
"idRequest":["01c2f632-eb14-40a0-a8b8-2239592d3319",
"0f75a172-b054-489b-a887-1b8f3cc12da1",
"44175ae8-965e-485a-a4ac-05ca79a25d5c"],
"type_request":["All categories"]
}
or
{
"type_request":["All categories"] ,
"period": 10
}
Default successful response
ANSWER BODY SCHEMA:
application/json
| Parameters | Type | Describe | |||
| response | object | object (ApiRequestStatus) | |||
| parametrRequest | Array of object | All information identification of all request. | |||
| idDocument | string | ID/Number document of person. Used in the block “request” | |||
| phoneNumber | string | Phone number of person. Can use next format ‘+380999999999’ or ‘380999999999’ or ‘0999999999’’. Used in the block “request” | |||
| idRequest | string | System id of request | |||
| status | string | The status of the current request. Possible options: Done, Panding |
|||
| requestDetails | Array of objects | Array of objects | |||
| idPpeers | string | peer id who shared information | |||
| groupData | string | Indicator of the type of information that we are looking for in this request. Possible values: ‘All categories’, ‘Address’, ‘Consumer Profile’, ‘Contacts’, ‘Credit History’, ‘Identity’, ‘Name’, ‘Services’, ‘Socio-Demographic Profile’, ‘Subscription’ |
|||
| fieldName | string | Field name | |||
| fieldValue | string | Field Value | |||
Example:
{
"parametrRequest": [
{
"idDocument": "TR6223-34",
"phoneNumber": " ",
"idRequest": "01c2f632-eb14-40a0-a8b8-2239592d3319",
"status": " Done",
"requestDetails": []
},
{
"idDocument": "6578203-TS",
"phoneNumber": "",
"idRequest": "0f75a172-b054-489b-a887-1b8f3cc12da1",
"status": "Pending",
"requestDetails": []
},
{
"idDocument": "9999999999",
"phoneNumber": " ",
"idRequest": "44175ae8-965e-485a-a4ac-05ca79a25d5c",
"status": " Done",
"requestDetails": [
{
"idPpeers": "TS5,",
"groupData": "All categories,",
"fieldName": " ID/NRC : Credentials Number,",
"fieldValue": "9999999999,"
},
{
"idPpeers": "TS5,",
"groupData": "All categories,",
"fieldName": " Phone Numbers : Personal Phone Number,",
"fieldValue": ","
},
{
"idPpeers": "TS5,",
"groupData": "Address,",
"fieldName": " Primary Address : Address,",
"fieldValue": "109 MIRALOMA DR Apt.102,"
},
{
"idPpeers": "TS5,",
"groupData": "Address,",
"fieldName": " Primary Address : Geolocation,",
"fieldValue": "12.14905;88.71655,"
},
{
"idPpeers": "TS5,",
"groupData": "Address,",
"fieldName": " Secondary Address : Address,",
"fieldValue": "33 REDONDO ST Apt.134,"
}
]
}
],
"response": {
"statusCode": 200,
"reasonPhrase": "OK",
"isSuccessStatusCode": true
}
}
Uploading data for contributing
All use cases can be achieved by using this API method. Everything from uploading a data, up to batch sending of data with a single API request.
Integration essentials and developer toolbox
POST /api/ApiUpload
Base URL: Please login to see full path.
AUTHORIZATIONS:
APIKeyHeader
REQUEST PARAMETERS SCHEMA:
application/json
| Parameters | Type | Describe |
| matchingFields | Array of string | List of loaded fields. All names are listed in strict order as all download data is transmitted. |
REQUEST BODY SCHEMA:
application/json
| Parameters | Type | Describe |
| valuedata | Array of string |
List of loaded data. Each line of data is formed in strict accordance with the list of fields that are specified in the request parameter. |
Default successful response
ANSWER BODY SCHEMA:
application/json
| Parameters | Describe |
| requestStatus |
object (ApiRequestStatus) |
Get the list of fields
A list of all the field names that you can exchange in the system CARMA can be obtained using this API method.
Integration essentials and developer toolbox
GET /api/FieldList
Base URL: Please login to see full path.
AUTHORIZATIONS:
APIKeyHeader
Default successful response
ANSWER BODY SCHEMA:
application/json
| Parameters | Type | Describe |
| NameField | Array of string | list of fields that can be passed through CARMA Network. |
